/* unity parser */
/* The content of this file is not valid YACC input as it stands, because of all the @ keywords.
 * These are to be processed by the program tools/stripat, under the control of the Makefiles
 * in src/c and src/java.
 */

%{
@!header
%}

@+c
%union {
        int i;
        float f;
        char c;
        char* s;
        struct unit_struct* u;
        struct unit_struct* uList;
}
@-c

/* tokens with values */
%token <i> INTEGER
%token <f> FLOAT
%token <s> STRING
/* tokens without values */
%token WHITESPACE
%token STARSTAR
%token CARET
%token DIVISION
%token DOT
%token STAR
%token OPEN_P
%token CLOSE_P

/* Note: types are a Bison/byacc extension to yacc */
%type <f> numeric_power
%type <u> unit
%type <uList> product_of_units unit_expression
%type <f> factor


/* the following two lines are really @bison, since they use bison-specific extension
   -- byacc doesn't understand it */
@=c %error-verbose
@=c %debug

%%

input:		  product_of_units {
                      @!input:product-of-units
                  }
                | factor product_of_units {
                      // note: something like "10^3 Hz" is parsed as 1e3 * Hz, and not 1 kHz
                      @!input:factor+product-of-units
                  }
@+fits
// The FITS spec isn't completely clear on the topic of 
// solidi, saying "Parentheses are used for symbol grouping and are
// strongly recommended whenever the order of operations might be
// subject to misinterpretation" and "The IAU style manual forbids
// the use of more than one solidus (/) character in a units
// string. However, since normal mathematical precedence rules apply
// in this context, more than one solidus may be used but is
// discouraged" (p27).  Therefore, it's not clear whether, for
// example, "kg/m s" should be parsed as "kg m-1 s-1", as "kg m-1 s", or
// forbidden on the grounds that 'normal mathematical precedence
// rules' would forbid it (it's probably arguable all ways, but I
// don't think that 'normal mathematical precedence rules' are going
// to resolve it).  Here, we resolve this by declaring that there can
// be only a single expression to the right of the solidus.  That is,
// we do not have "product_of_units DIVISION product_of_units" here.
//
// Note: it is I think a consequence of this that nothing can be
// successully parsed in two different grammars, with different
// meanings.  If the right-hand-side of the division could be a
// product_of_units, then "kg /m s" would parse in both FITS and OGIP,
// but mean "kg m-1 s-1" in FITS and "kg m-1 s" in OGIP.
                | product_of_units DIVISION unit_expression {
                      @!input:product-of-units+product-of-units
                  }
                | factor product_of_units DIVISION unit_expression {
                      @!input:factor+product-of-units+product-of-units
                  }
// The FITS spec may or may not be intended to permit "10+3 /m",
// but we don't (because ... for heavens' sake!)
                | DIVISION unit_expression {
                      @!input:division+unit-expression
                  }
@-fits
                ;

unit_expression:  unit {
                      @!unit
                  }                                
                | OPEN_P product_of_units CLOSE_P {
                      $$ = $2;
                  }
                ;

@+fits
product_of_units: unit_expression {
                      $$ = $1;
                  }
                | product_of_units product unit_expression {
                      @!product-of-units+product+unit-expression
                  }
                ;
@-fits

@+ogip,cds
// We conceive of the product_of_units as a sequence of terms 'times
// expression' or 'dividedby expression', multiplying them together
// after, in the latter case, reciprocating them.
product_of_units: unit_expression
                | division unit_expression {
                      @!division+unit-expression
                  }
                | product_of_units product unit_expression {
                      @!product-of-units+product+unit_expression
                  }
                | product_of_units division unit_expression {
                      @!product-of-units+division+unit_expression
                  }
                ;
@-ogip,cds

// We require the following prefix factors to be powers of ten,
// as an extra-syntactic condition
factor:           INTEGER power numeric_power { // eg 10^3
	              if ($1 != 10) {
                          yyerror("leading factors must be powers of ten"); // throws an exception
@=c                       YYERROR; // throw an error
                      }
@=c                   $$ = $3;
@=java                $$ = Double.valueOf($3);
                  }
@+fits,cds
// Represent exponents as a pair of integers, eg 10+3
                | INTEGER INTEGER {
                      if ($1 != 10) {
                          yyerror("leading factors must be powers of ten");
@=c                       YYERROR;
                      }
                      @!factor:integer+integer
                  }
@-fits,cds
@+ogip,cds
                | FLOAT {
                      @!factor:float
                  }
                | INTEGER {
                      @!factor:integer
                  }
@-
                ;

@+ogip
// OGIP recommends no whitespace after the slash
division: DIVISION | WHITESPACE DIVISION | WHITESPACE DIVISION WHITESPACE | DIVISION WHITESPACE;
@-
@=cds division: DIVISION

unit:             STRING       		{
                      @!string
                  }
@+!cds
                | STRING power numeric_power        {
                      @!string+power+numeric-power
                  }
@-!cds
@+fits,cds
                | STRING numeric_power        {
                      @!string+numeric-power
                  }
@-fits,cds
                ;

numeric_power:	  INTEGER {
@+ogip
                      if ($1 < 0) {
                          yyerror("Can't have bare negative power in exponent");
@=c                       YYERROR;
                      }
@-
                      $$ = $1;
                  }
@+!cds
                | OPEN_P INTEGER CLOSE_P {
                      $$ = $2;
                  }
                | OPEN_P FLOAT CLOSE_P {
                      $$ = $2;
                  }
                | OPEN_P INTEGER DIVISION INTEGER CLOSE_P {
                      // This is certainly OK for FITS, not clear for OGIP
                      $$ = ((float)$2)/((float)($4));
                  }
@-
                ;

@+fits
power:		  CARET
                | STARSTAR
                ;
@-fits
@+cds,ogip
power:		  STARSTAR;
@-

@=cds   product:	DOT;
@=fits	product:	WHITESPACE | STAR | DOT;
@=ogip	product:        WHITESPACE | STAR | WHITESPACE STAR | WHITESPACE STAR WHITESPACE | STAR WHITESPACE;

%%

@!user-code
