package uk.me.nxg.unity;

/**
 * A unit parser.
 */
abstract class Parser {

    static short INTEGER;
    static short FLOAT;
    static short PREFIX;
    static short STRING;
    static short WHITESPACE;
    static short STARSTAR;
    static short CARET;
    static short DIVISION;
    static short DOT;
    static short STAR;
    static short OPEN_P;
    static short CLOSE_P;
    static {
        // This is a bit cruddy -- does it even work?
        // This presumes that the parser generator will always produce
        // the same constants each time it processes a given grammar
        // -- that is, that the constants in each of the Parser_* are
        // the same.
        INTEGER    = Parser_fits.INTEGER;
        FLOAT      = Parser_fits.FLOAT;
        PREFIX     = Parser_fits.PREFIX;
        STRING     = Parser_fits.STRING;
        WHITESPACE = Parser_fits.WHITESPACE;
        STARSTAR   = Parser_fits.STARSTAR;
        CARET      = Parser_fits.CARET;
        DIVISION   = Parser_fits.DIVISION;
        DOT        = Parser_fits.DOT;
        STAR       = Parser_fits.STAR;
        OPEN_P     = Parser_fits.OPEN_P;
        CLOSE_P    = Parser_fits.CLOSE_P;
    }

    // These instance variables are defined here, intended to be
    // visible in the classes which extend this class.  The Makefile
    // ensures that those generated classes don't redeclare these
    // variables, and thus hide them.
    Yylex lexer;
    UnitVal yylval;
    protected OneUnit.Maker unitMaker = null;

    /**
     * Set the source of the text to parse
     */
    void setReader(java.io.Reader r) {
        lexer = new Yylex(r, this);
    }

    void setUnitMaker(OneUnit.Maker unitMaker) {
        this.unitMaker = unitMaker;
    }

    int parse() 
            throws UnitParserException {
        if (unitMaker == null) {
            throw new IllegalStateException("Parser: unitMaker not initialised (this shouldn't happen)");
        }
        return yyparse();
    }

    // The following methods are defined in the generated parsers
    abstract protected int yyparse()
            throws UnitParserException;
    abstract UnitExpr getParseResult();
}
